Welcome to Shape4D’s documentation! — Shape4D 0.08 documentation

# Welcome to Shape4D’s documentation!

## Here, we present a help document of Shape4D. The Shape4D is primarily designed for predicting shadows of solar beam on building

`At present, one can find a few fundamental calculation of geometry in Shape4D`

Current version 0.1.9

- About Shape4D
  - Functions of Shape4D
- Installation
  - Preparation
  - Package itself
- Before usage
  - Import Shape4D

- Creating point, line, and polygon
  - Point
  - Line and plane
  - Segement
  - Polygon
- Basic drawing
  - 1.Convex polygon
  - 2.Hollow four-sided polygon
  - 3.Transformation to 3D space
- Point and plane
  - Point against line
  - Point against plane
- Line against line, plane and polygon
  - Line vs line
  - Line vs plane
  - Line vs polygon
- Settings of precision

# Memo

Welcome to any reply

# Reference list

- Index

- Search Page